@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
-## Module Generic - ~/lib/Promise/Me.pm
-## Version v0.1.0
+## Promise - ~/lib/Promise/Me.pm
+## Version v0.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/05/28
@@ -104,7 +104,7 @@ BEGIN
     use constant SHARED_MEMORY_BLOCK => ( 64 * 1024 );
     our $SHARED  = {};
     our @TIED    = ();
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 sub import
@@ -2158,7 +2158,7 @@ Promise::Me - Fork Based Promise with Asynchronous Execution, Async, Await and S
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
@@ -2279,7 +2279,7 @@ Contrary to its JavaScript equivalent, you do not need to pass an array referenc
     # Works too, but not mandatory
     my @results = Promise::Me->all( [ $p1, $p2, $p3 ] );
 
-See also L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/all|Mozilla documentation> for more information.
+See also L<Mozilla documentation|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/all> for more information.
 
 =head2 race
 
@@ -2290,7 +2290,7 @@ Contrary to its JavaScript equivalent, you do not need to pass an array referenc
     # Works too, but not mandatory
     my @results = Promise::Me->race( [ $p1, $p2, $p3 ] );
 
-See also L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/race|Mozilla documentation> for more information.
+See also L<Mozilla documentation|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/race> for more information.
 
 =head1 EXPORTED FUNCTIONS
 
@@ -2336,7 +2336,7 @@ Of course, since, in our example above, C<fetch> would return a promise, you cou
         $dbi->disconnect;
     });
 
-See L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/async_function|Mozilla documentation> for more information on C<async>
+See L<Mozilla documentation|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/async_function> for more information on C<async>
 
 =head2 await
 
@@ -2425,7 +2425,7 @@ It is used to capture arguments so they can be passed to the code executed async
 
 =head2 exec
 
-This method is called at the end of the chain. It will prepare shared variable for the child process, lauch a child process using L<perlfunc/fork> and will call the next L</then> handler if the code executed successfully, or L</reject> if there was an error.
+This method is called at the end of the chain. It will prepare shared variable for the child process, launch a child process using L<perlfunc/fork> and will call the next L</then> handler if the code executed successfully, or L</reject> if there was an error.
 
 =head2 exit_bit
 
@@ -2437,7 +2437,7 @@ This corresponds to the integer value of the signal, if any, used to interrupt t
 
 =head2 exit_status
 
-This is the integer value of the exit for the asynchronous process. If a process exited normally, this value should be o.
+This is the integer value of the exit for the asynchronous process. If a process exited normally, this value should be 0.
 
 =head2 filter
 
@@ -2501,13 +2501,13 @@ This returns the L<Module::Generic::SharedMem> object used for sharing data and
 
 This is a boolean value which is set automatically when a promise is instantiated from L</async>.
 
-It enable subroutine arguments to be passed to the code being run asynchronously.
+It enables subroutine arguments to be passed to the code being run asynchronously.
 
 =head1 PRIVATE METHODS
 
 =head2 _browse
 
-Used for debug purpose only, this will print out the L<PPI> structure of the code filtered and parsed.
+Used for debugging purpose only, this will print out the L<PPI> structure of the code filtered and parsed.
 
 =head2 _parse
 
@@ -2519,7 +2519,7 @@ This is a common code called by either L</resolve> or L</reject>
 
 =head2 _set_exit_values
 
-This is called upo the exit of the asynchronous process to set some general value about how the process exited.
+This is called upon the exit of the asynchronous process to set some general value about how the process exited.
 
 See L</exit_bit>, L</exit_signal> and L</exit_status>
 
@@ -2533,7 +2533,7 @@ It is important to be able to share variables between processes in a seamless wa
 
 When the asynchronous process is executed, the main process first fork and from this point on all data is being duplicated in an impermeable way so that if a variable is modified, it would have no effect on its alter ego in the other process; thus the need for shareable variables.
 
-You can enable shared variables in two way:
+You can enable shared variables in two ways:
 
 =over 4
 
@@ -2659,11 +2659,10 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 L<Promise::XS>, L<Promise::E6>, L<Promise::AsyncAwait>, L<AnyEvent::XSPromises>, L<Async>, L<Promises>, L<Mojo::Promise>
 
-L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Using_promises|Mozilla documentation on promises>
+L<Mozilla documentation on promises|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Using_promises>
 
 =head1 COPYRIGHT & LICENSE
 
 Copyright(c) 2021 DEGUEST Pte. Ltd. DEGUEST Pte. Ltd.
 
 =cut
-
